Imports System.Drawing.Printing

Public Class PageSetup

    '
    ' ShowDialog
    '
    ' Display a PageSetupDialog to let the user set page size, page margins and orientation
    '
    Public Sub ShowDialog(ByVal tx As TXTextControl.TextControl)
        Dim Landscape As Boolean = (tx.PageSize.Width > tx.PageSize.Height)
        Dim psDlg As New PageSetupDialog()

        Try
            psDlg.PageSettings = New PageSettings()
            psDlg.PageSettings.PaperSize = GetTxPaperSize(tx.PageSize, Landscape)
            If (System.Globalization.RegionInfo.CurrentRegion.IsMetric) Then
                ' Workaround for a .NET framework issue: the dialog box should always 
                ' accept 1/100 inch, but it actually depends on the regional settings 
                ' which measurement is used.
                psDlg.PageSettings.Margins = New Margins( _
                    tx.PageMargins.Left * 2.54, _
                    tx.PageMargins.Right * 2.54, _
                    tx.PageMargins.Top * 2.54, _
                    tx.PageMargins.Bottom * 2.54)
            Else
                psDlg.PageSettings.Margins = New Margins( _
                    tx.PageMargins.Left, _
                    tx.PageMargins.Right, _
                    tx.PageMargins.Top, _
                    tx.PageMargins.Bottom)
            End If
            If (psDlg.ShowDialog() = DialogResult.OK) Then
                Landscape = psDlg.PageSettings.Landscape
                If Landscape Then
                    tx.PageSize = New Size(psDlg.PageSettings.PaperSize.Height, psDlg.PageSettings.PaperSize.Width)
                Else
                    tx.PageSize = New Size(psDlg.PageSettings.PaperSize.Width, psDlg.PageSettings.PaperSize.Height)
                End If
                tx.PageMargins = New TXTextControl.PageMargins( _
                    psDlg.PageSettings.Margins.Left, _
                    psDlg.PageSettings.Margins.Top, _
                    psDlg.PageSettings.Margins.Right, _
                    psDlg.PageSettings.Margins.Bottom)
            End If
        Catch ex As Exception
            MsgBox("Error setting page size or margins.")
        End Try
    End Sub

    '
    ' GetTxPaperSize
    ' 
    ' Find a paper size that matches Text Control's current page size settings. 
    '
    Private Function GetTxPaperSize(ByVal DocSize As Size, ByVal Landscape As Boolean) As PaperSize
        Dim ps As PaperSize
        Dim pdoc As New PrintDocument()

        ' Swap values if Landscape.
        If Landscape Then
            DocSize = New Size(DocSize.Height, DocSize.Width) ' swap
        End If

        ' Find a matching page size in the printer's paper size collection
        For Each ps In pdoc.PrinterSettings.PaperSizes
            If Math.Abs(ps.Height - DocSize.Height) = 0 And Math.Abs(ps.Width - DocSize.Width) = 0 Then
                GetTxPaperSize = ps
                Exit For
            End If
        Next

    End Function

End Class
